# vs-colabi



## Getting started

a library allow to use vs code tunnel in google colab 
## Installation

```bash
pip install vs-colabi
```

## Example

```python
from vscolabi import configure
configure()
```
Steps  : 
*   a button will be display it --> click .
*   this button once is clicked will show pop frame , paste the code inside input , (code is copy the code to clipboard automaitcly ).
*   after contunue the steps in the pop up , it will display a buttons with text open vscode 